@@ -23,7 +23,7 @@ from flask_login import current_user
 # Enable the following: from flask.ext.user import login_required, roles_required
 from .decorators import *
 
-__version__ = '0.5.3'
+__version__ = '0.5.4'
 
 def _flask_user_context_processor():
     """ Make 'user_manager' available to Jinja2 templates"""
@@ -124,6 +124,10 @@ class UserManager(object):
                     translations.gettext,
                     translations.ngettext,
                     newstyle=True)
+        else:
+            app.jinja_env.add_extension('jinja2.ext.i18n')
+            app.jinja_env.install_null_translations()
+
 
         # Create password_crypt_context if needed
         if not self.password_crypt_context:
