@@ -16,6 +16,9 @@ def set_default_settings(user_manager, app_config):
     obsoleted_enable_retype_passwords  = sd('USER_ENABLE_RETYPE_PASSWORDS',    True)
     obsoleted_enable_usernames         = sd('USER_ENABLE_USERNAMES',           True)
 
+    # General settings
+    um.product_name             = sd('USER_PRODUCT_NAME', 'Flask-User')
+
     # Set default features
     um.enable_change_password   = sd('USER_ENABLE_CHANGE_PASSWORD',     True)
     um.enable_change_username   = sd('USER_ENABLE_CHANGE_USERNAME',     True)
@@ -28,32 +31,48 @@ def set_default_settings(user_manager, app_config):
     um.enable_multiple_emails   = sd('USER_ENABLE_MULTIPLE_EMAILS',     False)
 
     # Set default settings
-    um.confirm_email_expiration = sd('USER_CONFIRM_EMAIL_EXPIRATION',   2*24*3600)   # 2 days
-    um.invite_expiration        = sd('USER_INVITE_EXPIRATION',          90*24*3600)  # 90 days
-    um.password_hash_mode       = sd('USER_PASSWORD_HASH_MODE',         'passlib')
-    um.password_hash            = sd('USER_PASSWORD_HASH',              'bcrypt')
-    um.password_salt            = sd('USER_PASSWORD_SALT',              app_config['SECRET_KEY'])
-    um.reset_password_expiration= sd('USER_RESET_PASSWORD_EXPIRATION',  2*24*3600)   # 2 days
-    um.require_invitation       = sd('USER_REQUIRE_INVITATION',         False)
-    um.send_password_changed_email = sd('USER_SEND_PASSWORD_CHANGED_EMAIL',   um.enable_email)
-    um.send_registered_email       = sd('USER_SEND_REGISTERED_EMAIL',         um.enable_email)
-    um.send_username_changed_email = sd('USER_SEND_USERNAME_CHANGED_EMAIL',   um.enable_email)
-    um.auto_login               = sd('USER_AUTO_LOGIN',                 True)
+    um.auto_login                  = sd('USER_AUTO_LOGIN',                 True)
+    um.auto_login_at_login         = sd('USER_AUTO_LOGIN_AT_LOGIN',        um.auto_login)
+    um.auto_login_after_register   = sd('USER_AUTO_LOGIN_AFTER_REGISTER',  um.auto_login)
+    um.auto_login_after_confirm    = sd('USER_AUTO_LOGIN_AFTER_CONFIRM',   um.auto_login)
+    um.confirm_email_expiration    = sd('USER_CONFIRM_EMAIL_EXPIRATION',   2*24*3600)   # 2 days
+    um.invite_expiration           = sd('USER_INVITE_EXPIRATION',          90*24*3600)  # 90 days
+    um.password_hash_mode          = sd('USER_PASSWORD_HASH_MODE',         'passlib')
+    um.password_hash               = sd('USER_PASSWORD_HASH',              'bcrypt')
+    um.password_salt               = sd('USER_PASSWORD_SALT',              app_config['SECRET_KEY'])
+    um.reset_password_expiration   = sd('USER_RESET_PASSWORD_EXPIRATION',  2*24*3600)   # 2 days
+    um.require_invitation          = sd('USER_REQUIRE_INVITATION',         False)
+    um.send_password_changed_email = sd('USER_SEND_PASSWORD_CHANGED_EMAIL',um.enable_email)
+    um.send_registered_email       = sd('USER_SEND_REGISTERED_EMAIL',      um.enable_email)
+    um.send_username_changed_email = sd('USER_SEND_USERNAME_CHANGED_EMAIL',um.enable_email)
 
     # Set default URLs
-    um.change_password_url      = sd('USER_CHANGE_PASSWORD_URL',        '/user/change-password')
-    um.change_username_url      = sd('USER_CHANGE_USERNAME_URL',        '/user/change-username')
-    um.confirm_email_url        = sd('USER_CONFIRM_EMAIL_URL',          '/user/confirm-email/<token>')
-    um.email_action_url         = sd('USER_EMAIL_ACTION_URL',           '/user/email/<id>/<action>')
-    um.forgot_password_url      = sd('USER_FORGOT_PASSWORD_URL',        '/user/forgot-password')
-    um.login_url                = sd('USER_LOGIN_URL',                  '/user/sign-in')
-    um.logout_url               = sd('USER_LOGOUT_URL',                 '/user/sign-out')
-    um.manage_emails_url        = sd('USER_MANAGE_EMAILS_URL',          '/user/manage-emails')
-    um.register_url             = sd('USER_REGISTER_URL',               '/user/register')
-    um.resend_confirm_email_url = sd('USER_RESEND_CONFIRM_EMAIL_URL',   '/user/resend-confirm-email')
-    um.reset_password_url       = sd('USER_RESET_PASSWORD_URL',         '/user/reset-password/<token>')
-    um.unauthenticated_url      = sd('USER_UNAUTHENTICATED_URL',        um.login_url)
-    um.unauthorized_url         = sd('USER_UNAUTHORIZED_URL',           '/')
+    um.change_password_url       = sd('USER_CHANGE_PASSWORD_URL',        '/user/change-password')
+    um.change_username_url       = sd('USER_CHANGE_USERNAME_URL',        '/user/change-username')
+    um.confirm_email_url         = sd('USER_CONFIRM_EMAIL_URL',          '/user/confirm-email/<token>')
+    um.email_action_url          = sd('USER_EMAIL_ACTION_URL',           '/user/email/<id>/<action>')
+    um.forgot_password_url       = sd('USER_FORGOT_PASSWORD_URL',        '/user/forgot-password')
+    um.login_url                 = sd('USER_LOGIN_URL',                  '/user/sign-in')
+    um.logout_url                = sd('USER_LOGOUT_URL',                 '/user/sign-out')
+    um.manage_emails_url         = sd('USER_MANAGE_EMAILS_URL',          '/user/manage-emails')
+    um.register_url              = sd('USER_REGISTER_URL',               '/user/register')
+    um.resend_confirm_email_url  = sd('USER_RESEND_CONFIRM_EMAIL_URL',   '/user/resend-confirm-email')
+    um.reset_password_url        = sd('USER_RESET_PASSWORD_URL',         '/user/reset-password/<token>')
+
+    # Set default ENDPOINTs
+    home_endpoint = ''
+    login_endpoint = 'user.login'
+    um.after_change_password_endpoint      = sd('USER_AFTER_CHANGE_PASSWORD_ENDPOINT',      home_endpoint)
+    um.after_change_username_endpoint      = sd('USER_AFTER_CHANGE_USERNAME_ENDPOINT',      home_endpoint)
+    um.after_login_endpoint                = sd('USER_AFTER_LOGIN_ENDPOINT',                home_endpoint)
+    um.after_logout_endpoint               = sd('USER_AFTER_LOGOUT_ENDPOINT',               login_endpoint)
+    um.after_register_endpoint             = sd('USER_AFTER_REGISTER_ENDPOINT',             home_endpoint)
+    um.after_confirm_endpoint              = sd('USER_AFTER_CONFIRM_ENDPOINT',              home_endpoint)
+    um.after_resend_confirm_email_endpoint = sd('USER_AFTER_RESEND_CONFIRM_EMAIL_ENDPOINT', home_endpoint)
+    um.after_forgot_password_endpoint      = sd('USER_AFTER_FORGOT_PASSWORD_ENDPOINT',      home_endpoint)
+    um.unauthenticated_endpoint            = sd('USER_UNAUTHENTICATED_ENDPOINT',            login_endpoint)
+    um.unauthorized_endpoint               = sd('USER_UNAUTHORIZED_ENDPOINT',               home_endpoint)
+
     # Set default template files
     um.change_password_template = sd('USER_CHANGE_PASSWORD_TEMPLATE',  'flask_user/change_password.html')
     um.change_username_template = sd('USER_CHANGE_USERNAME_TEMPLATE',  'flask_user/change_username.html')
@@ -63,6 +82,7 @@ def set_default_settings(user_manager, app_config):
     um.register_template        = sd('USER_REGISTER_TEMPLATE',         'flask_user/register.html')
     um.resend_confirm_email_template = sd('USER_RESEND_CONFIRM_EMAIL_TEMPLATE', 'flask_user/resend_confirm_email.html')
     um.reset_password_template       = sd('USER_RESET_PASSWORD_TEMPLATE',       'flask_user/reset_password.html')
+
     # Set default email template files
     um.confirm_email_email_template    = sd('USER_CONFIRM_EMAIL_EMAIL_TEMPLATE',    'flask_user/emails/confirm_email')
     um.forgot_password_email_template  = sd('USER_FORGOT_PASSWORD_EMAIL_TEMPLATE',  'flask_user/emails/forgot_password')
@@ -70,6 +90,7 @@ def set_default_settings(user_manager, app_config):
     um.registered_email_template       = sd('USER_REGISTERED_EMAIL_TEMPLATE',       'flask_user/emails/registered')
     um.username_changed_email_template = sd('USER_USERNAME_CHANGED_EMAIL_TEMPLATE', 'flask_user/emails/username_changed')
 
+
 def check_settings(user_manager):
     """ Verify config combinations. Produce a helpful error messages for inconsistent combinations."""
     # Define custom Exception
